# frozen_string_literal: true

module Hermes
  # Lessor serializer
  class LessorSerializer < Hermes::ApplicationSerializer
    attributes %i[
      als_id
      title
      siret
      siren
      is_root
      root_id
      parent_id
      api_id
      rpls_id
      affiliate
      housing_actual_flow_nb
      housing_targeted_flow_nb
      new_housing_actual_flow_nb
      new_housing_targeted_flow_nb
      housing_offer_ids
      agency_ids
      lessor_objective_ids
      group_id
      supervisor_group_id
      manager_group_id
      manual_mode
    ]

    type 'lessors'
    def manual_mode
      object&.manual_mode if object.respond_to? :manual_mode
    end
    def housing_offer_ids
      return if instance_options[:reduced]
      object.housing_offer_ids.map(&:to_s)
    end

    def agency_ids
      object.agency_ids.map(&:to_s)
    end

    def lessor_objective_ids
      return if instance_options[:reduced]
      object.lessor_objective_ids.map(&:to_s)
    end

    def housing_actual_flow_nb
      object.housing_actual_flow_number
    end

    def housing_targeted_flow_nb
      object.housing_targeted_flow_number
    end

    def new_housing_actual_flow_nb
      object.new_housing_actual_flow_number
    end

    def new_housing_targeted_flow_nb
      object.new_housing_targeted_flow_number
    end

    def group_id
      object.group_id&.to_s
    end

    def supervisor_group_id
      object.supervisor_group_id
    end

    def manager_group_id
      object.manager_group_id
    end

    def current_user_right
      right = nil
      current_user.group_ids.each do |id|
        right = 'reader' if id == object.group_id
        right = 'user' if id == object.supervisor_group_id
        right = 'administrator' if id == object.manager_group_id
      end
      right
    end
    
    # has_one :image
  end
end
